
# Slot: extensions


a tag/text tuple attached to an arbitrary element

URI: [linkml:extensions](https://w3id.org/linkml/extensions)


## Domain and Range

extensible &#8594;  <sub>0..\*</sub> extension

## Parents


## Children

 *  annotations

## Used by

 * annotation
 * class_definition
 * definition
 * [Element](Element.md)
 * enum_definition
 * extensible
 * extension
 * permissible_value
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition
 * unique_key
